@@ -8,16 +8,16 @@ extern "C" {
 R_LIB_VERSION_HEADER(r_heap_glibc);
 
 #define PRINTF_A(color, fmt , ...) r_cons_printf (color fmt Color_RESET, __VA_ARGS__)
-#define PRINTF_YA(fmt, ...) PRINTF_A (Color_YELLOW, fmt, __VA_ARGS__)
-#define PRINTF_GA(fmt, ...) PRINTF_A (Color_GREEN, fmt, __VA_ARGS__)
-#define PRINTF_BA(fmt, ...) PRINTF_A (Color_BLUE, fmt, __VA_ARGS__)
-#define PRINTF_RA(fmt, ...) PRINTF_A (Color_RED, fmt, __VA_ARGS__)
+#define PRINTF_YA(fmt, ...) PRINTF_A ("%s", fmt, pal->offset, __VA_ARGS__)
+#define PRINTF_GA(fmt, ...) PRINTF_A ("%s", fmt, pal->args, __VA_ARGS__)
+#define PRINTF_BA(fmt, ...) PRINTF_A ("%s", fmt, pal->num, __VA_ARGS__)
+#define PRINTF_RA(fmt, ...) PRINTF_A ("%s", fmt, pal->invalid, __VA_ARGS__)
 
 #define PRINT_A(color, msg) r_cons_print (color msg Color_RESET)
-#define PRINT_YA(msg) PRINT_A (Color_YELLOW, msg)
-#define PRINT_GA(msg) PRINT_A (Color_GREEN, msg)
-#define PRINT_BA(msg) PRINT_A (Color_BLUE, msg)
-#define PRINT_RA(msg) PRINT_A (Color_RED, msg)
+#define PRINT_YA(msg) r_cons_printf ("%s" msg Color_RESET, pal->offset)
+#define PRINT_GA(msg) r_cons_printf ("%s" msg Color_RESET, pal->args)
+#define PRINT_BA(msg) r_cons_printf ("%s" msg Color_RESET, pal->num)
+#define PRINT_RA(msg) r_cons_printf ("%s" msg Color_RESET, pal->invalid)
 
 #define PREV_INUSE 0x1
 #define IS_MMAPPED 0x2
@@ -36,6 +36,16 @@ R_LIB_VERSION_HEADER(r_heap_glibc);
 #define TCACHE_MAX_BINS 64
 #define TCACHE_FILL_COUNT 7
 
+#define MMAP_ALIGN_32 0x14
+#define MMAP_ALIGN_64 0x18
+#define MMAP_OFFSET 0x8
+
+#define HDR_SZ_32 0x8
+#define HDR_SZ_64 0x10
+#define TC_HDR_SZ 0x10
+#define TC_SZ_32 0x0
+#define TC_SZ_64 0x10
+
 #define largebin_index_32(size)				       \
 (((((ut32)(size)) >>  6) <= 38)?  56 + (((ut32)(size)) >>  6): \
  ((((ut32)(size)) >>  9) <= 20)?  91 + (((ut32)(size)) >>  9): \
@@ -110,6 +120,7 @@ typedef struct r_malloc_state_32 {
 	unsigned int binmap[BINMAPSIZE];        /* bitmap of bins */
 	ut32 next;                              /* double linked list of chunks */
 	ut32 next_free;                         /* double linked list of free chunks */
+	unsigned int attached_threads;          /* threads attached */
 	ut32 system_mem;                        /* current allocated memory of current arena */
 	ut32 max_system_mem;                    /* maximum system memory */
 } RHeap_MallocState_32;
@@ -124,18 +135,19 @@ typedef struct r_malloc_state_64 {
 	unsigned int binmap[BINMAPSIZE];        /* bitmap of bins */
 	ut64 next;                              /* double linked list of chunks */
 	ut64 next_free;                         /* double linked list of free chunks */
+	unsigned int attached_threads;          /* threads attached */
 	ut64 system_mem;                        /* current allocated memory of current arena */
 	ut64 max_system_mem;                    /* maximum system memory */
 } RHeap_MallocState_64;
 
 typedef struct r_tcache_perthread_struct_32 {
-	ut8 counts[TCACHE_MAX_BINS];
-	unsigned int *entries[TCACHE_MAX_BINS];
+	ut16 counts[TCACHE_MAX_BINS];
+	ut32 entries[TCACHE_MAX_BINS];
 } RHeapTcache_32;
 
 typedef struct r_tcache_perthread_struct_64 {
-	ut8 counts[TCACHE_MAX_BINS];
-	unsigned int *entries[TCACHE_MAX_BINS];
+	ut16 counts[TCACHE_MAX_BINS];
+	ut64 entries[TCACHE_MAX_BINS];
 } RHeapTcache_64;
 
 typedef struct r_malloc_state_tcache_32 {
