@@ -1,6 +1,7 @@
 #ifndef R2_TH_H
 #define R2_TH_H
 
+#define _GNU_SOURCE
 #include "r_types.h"
 
 #define HAVE_PTHREAD 1
@@ -18,6 +19,23 @@
 #define __GNU
 #include <semaphore.h>
 #include <pthread.h>
+#if __linux__
+#include <sched.h>
+#endif
+#if __linux__ && __GLIBC_MINOR < 12
+#define HAVE_PTHREAD_NP 0
+#else
+#define HAVE_PTHREAD_NP 1
+#endif
+#if __APPLE__
+#include <pthread.h>
+#endif
+#if __FreeBSD__ || __OpenBSD__ || __DragonFly__
+#if __FreeBSD__
+#include <sys/cpuset.h>
+#endif
+#include <pthread_np.h>
+#endif
 #define R_TH_TID pthread_t
 #define R_TH_LOCK_T pthread_mutex_t
 #define R_TH_COND_T pthread_cond_t
@@ -39,7 +57,6 @@ typedef struct r_th_sem_t {
 } RThreadSemaphore;
 
 typedef struct r_th_lock_t {
-	int refs;
 	R_TH_LOCK_T lock;
 } RThreadLock;
 
@@ -49,15 +66,11 @@ typedef struct r_th_cond_t {
 
 typedef struct r_th_t {
 	R_TH_TID tid;
-#if HAVE_PTHREAD
-	pthread_mutex_t _mutex;
-	pthread_cond_t _cond;
-#endif
 	RThreadLock *lock;
 	R_TH_FUNCTION(fun);
 	void *user;    // user pointer
 	int running;
-	int breaked;   // thread aims to be interruped
+	int breaked;   // thread aims to be interrupted
 	int delay;     // delay the startup of the thread N seconds
 	int ready;     // thread is properly setup
 } RThread;
@@ -76,9 +89,10 @@ R_API void r_th_break(RThread *th);
 R_API void *r_th_free(RThread *th);
 R_API void *r_th_kill_free(RThread *th);
 R_API bool r_th_kill(RThread *th, bool force);
-R_API bool r_th_pause(RThread *th, bool enable);
-R_API bool r_th_try_pause(RThread *th);
 R_API R_TH_TID r_th_self(void);
+R_API bool r_th_setname(RThread *th, const char *name);
+R_API bool r_th_getname(RThread *th, char *name, size_t len);
+R_API bool r_th_setaffinity(RThread *th, int cpuid);
 
 R_API RThreadSemaphore *r_th_sem_new(unsigned int initial);
 R_API void r_th_sem_free(RThreadSemaphore *sem);
@@ -87,12 +101,12 @@ R_API void r_th_sem_wait(RThreadSemaphore *sem);
 
 R_API RThreadLock *r_th_lock_new(bool recursive);
 R_API int r_th_lock_wait(RThreadLock *th);
-R_API int r_th_lock_check(RThreadLock *thl);
+R_API int r_th_lock_tryenter(RThreadLock *thl);
 R_API int r_th_lock_enter(RThreadLock *thl);
 R_API int r_th_lock_leave(RThreadLock *thl);
 R_API void *r_th_lock_free(RThreadLock *thl);
 
-R_API RThreadCond *r_th_cond_new();
+R_API RThreadCond *r_th_cond_new(void);
 R_API void r_th_cond_signal(RThreadCond *cond);
 R_API void r_th_cond_signal_all(RThreadCond *cond);
 R_API void r_th_cond_wait(RThreadCond *cond, RThreadLock *lock);
