@@ -2,6 +2,7 @@
 #define R2_VECTOR_H
 
 #include <r_types.h>
+#include <r_util/r_assert.h>
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -68,7 +69,8 @@ R_API void r_vector_free(RVector *vec);
 // the returned vector will have the same capacity as vec.
 R_API RVector *r_vector_clone(RVector *vec);
 
-static inline bool r_vector_empty(RVector *vec) {
+static inline bool r_vector_empty(const RVector *vec) {
+	r_return_val_if_fail (vec, false);
 	return vec->len == 0;
 }
 
@@ -122,9 +124,13 @@ R_API void *r_vector_shrink(RVector *vec);
  * }
  */
 #define r_vector_foreach(vec, it) \
-	if ((vec) && (vec)->a) \
+	if (!r_vector_empty (vec)) \
 		for (it = (void *)(vec)->a; (char *)it != (char *)(vec)->a + ((vec)->len * (vec)->elem_size); it = (void *)((char *)it + (vec)->elem_size))
 
+#define r_vector_enumerate(vec, it, i) \
+	if (!r_vector_empty (vec)) \
+		for (it = (void *)(vec)->a, i = 0; i < (vec)->len; it = (void *)((char *)it + (vec)->elem_size), i++)
+
 
 // RPVector
 
@@ -154,15 +160,29 @@ static inline bool r_pvector_empty(RPVector *vec) {
 	return r_pvector_len (vec) == 0;
 }
 
+// returns a pointer to the offset inside the array where the element of the index lies.
+static inline void **r_pvector_index_ptr(RPVector *vec, size_t index) {
+	return ((void **)vec->v.a) + index;
+}
+
+// same as r_pvector_index_ptr(<vec>, 0)
+static inline void **r_pvector_data(RPVector *vec) {
+	return (void **)vec->v.a;
+}
+
 // returns the respective pointer inside the vector if x is found or NULL otherwise.
 R_API void **r_pvector_contains(RPVector *vec, void *x);
 
 // removes and returns the pointer at the given index. Does not call free.
 R_API void *r_pvector_remove_at(RPVector *vec, size_t index);
 
+// removes the element x, if present. Does not call free.
+R_API void r_pvector_remove_data(RPVector *vec, void *x);
+
 // like r_vector_insert, but the pointer x is the actual data to be inserted.
 static inline void **r_pvector_insert(RPVector *vec, size_t index, void *x) {
-	return (void **)r_vector_insert (&vec->v, index, &x); }
+	return (void **)r_vector_insert (&vec->v, index, &x);
+}
 
 // like r_vector_insert_range.
 static inline void **r_pvector_insert_range(RPVector *vec, size_t index, void **first, size_t count) {
@@ -209,6 +229,10 @@ static inline void **r_pvector_shrink(RPVector *vec) {
 #define r_pvector_foreach(vec, it) \
 	for (it = (void **)(vec)->v.a; it != (void **)(vec)->v.a + (vec)->v.len; it++)
 
+// like r_pvector_foreach() but inverse
+#define r_pvector_foreach_prev(vec, it) \
+	for (it = ((vec)->v.len == 0 ? NULL : (void **)(vec)->v.a + (vec)->v.len - 1); it != NULL && it != (void **)(vec)->v.a - 1; it--)
+
 /*
  * example:
  *
